@@ -9,7 +9,6 @@
 #include "logging.h"
 
 #include "applicationcontroller.h"
-#include "countrymodel.h"
 #include "developmentmodecontroller.h"
 #include "documentmanager.h"
 #include "documentsmodel.h"
@@ -18,6 +17,7 @@
 #include "livedatamanager.h"
 #include "localizer.h"
 #include "locationinformation.h"
+#include "locationinformationdelegatecontroller.h"
 #include "mapdownloadmanager.h"
 #include "navigationcontroller.h"
 #include "notificationconfigcontroller.h"
@@ -31,6 +31,7 @@
 #include "statisticstimerangemodel.h"
 #include "tickettokenmodel.h"
 #include "timelinedelegatecontroller.h"
+#include "timelinesectiondelegatecontroller.h"
 #include "transferdelegatecontroller.h"
 #include "transfermanager.h"
 #include "tripgroupinfoprovider.h"
@@ -109,13 +110,14 @@ void registerApplicationTypes()
     qmlRegisterUncreatableType<TimelineModel>("org.kde.itinerary", 1, 0, "TimelineModel", {});
     qmlRegisterUncreatableType<Transfer>("org.kde.itinerary", 1, 0, "Transfer", {});
 
-    qmlRegisterType<CountryModel>("org.kde.itinerary", 1, 0, "CountryModel");
     qmlRegisterType<DocumentsModel>("org.kde.itinerary", 1, 0, "DocumentsModel");
+    qmlRegisterType<LocationInformationDelegateController>("org.kde.itinerary", 1, 0, "LocationInformationDelegateController");
     qmlRegisterType<QSortFilterProxyModel>("org.kde.itinerary", 1, 0, "SortFilterProxyModel"); // TODO use this from kitemmodels?
     qmlRegisterType<StatisticsModel>("org.kde.itinerary", 1, 0, "StatisticsModel");
     qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
     qmlRegisterType<TicketTokenModel>("org.kde.itinerary", 1, 0, "TicketTokenModel");
     qmlRegisterType<TimelineDelegateController>("org.kde.itinerary", 1, 0, "TimelineDelegateController");
+    qmlRegisterType<TimelineSectionDelegateController>("org.kde.itinerary", 1, 0, "TimelineSectionDelegateController");
     qmlRegisterType<TransferDelegateController>("org.kde.itinerary", 1, 0, "TransferDelegateController");
     qmlRegisterType<WeatherForecastModel>("org.kde.itinerary", 1, 0, "WeatherForecastModel");
 }
@@ -130,16 +132,14 @@ static TransferManager *s_tranferManager = nullptr;
 static TripGroupManager *s_tripGroupManager = nullptr;
 static LiveDataManager *s_liveDataMnager = nullptr;
 static WeatherForecastManager *s_weatherForecastManager = nullptr;
+static TimelineModel *s_timelineModel = nullptr;
 static TripGroupInfoProvider s_tripGroupInfoProvider;
 static TripGroupProxyModel *s_tripGroupProxyModel = nullptr;
 static MapDownloadManager *s_mapDownloadManager = nullptr;
 static HealthCertificateManager *s_healthCertificateManager = nullptr;
 
 #define REGISTER_SINGLETON_INSTANCE(Class, Instance) \
-    qmlRegisterSingletonType<Class>("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine *engine, QJSEngine*) -> QObject* { \
-        engine->setObjectOwnership(Instance, QQmlEngine::CppOwnership); \
-        return Instance; \
-    });
+    qmlRegisterSingletonInstance<Class>("org.kde.itinerary", 1, 0, #Class, Instance);
 
 #define REGISTER_SINGLETON_GADGET_INSTANCE(Class, Instance) \
     qmlRegisterSingletonType("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine *engine, QJSEngine*) -> QJSValue { \
@@ -163,6 +163,7 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_INSTANCE(TripGroupManager, s_tripGroupManager)
     REGISTER_SINGLETON_INSTANCE(LiveDataManager, s_liveDataMnager)
     REGISTER_SINGLETON_INSTANCE(WeatherForecastManager, s_weatherForecastManager)
+    REGISTER_SINGLETON_INSTANCE(TimelineModel, s_timelineModel)
     REGISTER_SINGLETON_INSTANCE(TripGroupProxyModel, s_tripGroupProxyModel)
     REGISTER_SINGLETON_INSTANCE(MapDownloadManager, s_mapDownloadManager)
     REGISTER_SINGLETON_INSTANCE(HealthCertificateManager, s_healthCertificateManager)
@@ -178,6 +179,8 @@ void registerApplicationSingletons()
 }
 
 #undef REGISTER_SINGLETON_INSTANCE
+#undef REGISTER_SINGLETON_GADGET_INSTANCE
+#undef REGISTER_SINGLETON_GADGET_FACTORY
 
 void handleCommandLineArguments(ApplicationController *appController, const QStringList &args, bool isTemporary, const QString &page)
 {
@@ -207,9 +210,10 @@ int main(int argc, char **argv)
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     QCoreApplication::setApplicationVersion(QStringLiteral(ITINERARY_VERSION_STRING));
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     QQuickStyle::setStyle(QStringLiteral("Material"));
@@ -230,7 +234,7 @@ int main(int argc, char **argv)
     aboutData.setLicense(KAboutLicense::LGPL_V2, KAboutLicense::OrLaterVersions);
     aboutData.setHomepage(QStringLiteral("https://apps.kde.org/itinerary"));
     aboutData.setShortDescription(i18n("Digital Travel Assistant"));
-    aboutData.setCopyrightStatement(i18n("Copyright © 2018-2021 The KDE Community"));
+    aboutData.setCopyrightStatement(i18n("Copyright © 2018-%1 The KDE Community", QStringLiteral("2022")));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
@@ -301,6 +305,7 @@ int main(int argc, char **argv)
     timelineModel.setTransferManager(&transferManager);
     timelineModel.setTripGroupManager(&tripGroupMgr);
     QObject::connect(&settings, &Settings::homeCountryIsoCodeChanged, &timelineModel, &TimelineModel::setHomeCountryIsoCode);
+    s_timelineModel = &timelineModel;
 
     TripGroupProxyModel tripGroupProxy;
     tripGroupProxy.setSourceModel(&timelineModel);
